@@ -4,7 +4,7 @@
 # Description:  Read/write FujiFilm maker notes and RAF images
 #
 # Revisions:    11/25/2003 - P. Harvey Created
-#               11/14/2007 - PH Added abilty to write RAF images
+#               11/14/2007 - PH Added ability to write RAF images
 #
 # References:   1) http://park2.wakwak.com/~tsuruzoh/Computer/Digicams/exif-e.html
 #               2) http://homepage3.nifty.com/kamisaka/makernote/makernote_fuji.htm (2007/09/11)
@@ -31,7 +31,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.75';
+$VERSION = '1.81';
 
 sub ProcessFujiDir($$$);
 sub ProcessFaceRec($$$);
@@ -145,6 +145,8 @@ my %faceCategories = (
         Writable => 'int16u',
         PrintConv => {
             0x0   => 'Auto',
+            0x1   => 'Auto (white priority)', #forum10890
+            0x2   => 'Auto (ambiance priority)', #forum10890
             0x100 => 'Daylight',
             0x200 => 'Cloudy',
             0x300 => 'Daylight Fluorescent',
@@ -302,6 +304,7 @@ my %faceCategories = (
         PrintConv => {
             0 => 'Auto',
             1 => 'Manual',
+            65535 => 'Movie', #forum10766
         },
     },
     0x1022 => { #8/forum6579
@@ -373,6 +376,7 @@ my %faceCategories = (
             0x1a => 'Portrait 2', #PH (NC, T500, maybe "Smile & Shoot"?)
             0x1b => 'Dog Face Detection', #7
             0x1c => 'Cat Face Detection', #7
+            0x30 => 'HDR', #forum10799
             0x40 => 'Advanced Filter',
             0x100 => 'Aperture-priority AE',
             0x200 => 'Shutter speed priority AE',
@@ -464,6 +468,7 @@ my %faceCategories = (
         PrintConv => '$val > 0 ? "+$val" : $val',
         PrintConvInv => '$val + 0',
     },
+    # 0x104b - BWAdjustment for Green->Magenta (forum10800)
     0x104d => { #forum9634
         Name => 'CropMode',
         Writable => 'int16u',
@@ -484,6 +489,7 @@ my %faceCategories = (
             3 => 'Electronic Front Curtain', #10
         },
     },
+    # 0x1100 - This may not work well for newer cameras (ref forum12682)
     0x1100 => [{
         Name => 'AutoBracketing',
         Condition => '$$self{Model} eq "X-T3"',
@@ -502,6 +508,7 @@ my %faceCategories = (
             0 => 'Off',
             1 => 'On',
             2 => 'No flash & flash', #3
+            6 => 'Pixel Shift', #IB (GFX100S)
         },
     }],
     0x1101 => {
@@ -512,10 +519,12 @@ my %faceCategories = (
         Name => 'DriveSettings',
         SubDirectory => { TagTable => 'Image::ExifTool::FujiFilm::DriveSettings' },
     },
+    0x1105 => { Name => 'PixelShiftShots',  Writable => 'int16u' }, #IB
+    0x1106 => { Name => 'PixelShiftOffset', Writable => 'rational64s', Count => 2 }, #IB
     # (0x1150-0x1152 exist only for Pro Low-light and Pro Focus PictureModes)
-    # 0x1150 - Pro Low-light - val=1; Pro Focus - val=2 (ref 7)
-    # 0x1151 - Pro Low-light - val=4 (number of pictures taken?); Pro Focus - val=2,3 (ref 7)
-    # 0x1152 - Pro Low-light - val=1,3,4 (stacked pictures used?); Pro Focus - val=1,2 (ref 7)
+    # 0x1150 - Pro Low-light - val=1; Pro Focus - val=2 (ref 7); HDR - val=128 (forum10799)
+    # 0x1151 - Pro Low-light - val=4 (number of pictures taken?); Pro Focus - val=2,3 (ref 7); HDR - val=3 (forum10799)
+    # 0x1152 - Pro Low-light - val=1,3,4 (stacked pictures used?); Pro Focus - val=1,2 (ref 7); HDR - val=3 (forum10799)
     0x1153 => { #forum7668
         Name => 'PanoramaAngle',
         Writable => 'int16u',
@@ -617,6 +626,8 @@ my %faceCategories = (
             0x600 => 'Classic Chrome', #forum6109
             0x700 => 'Eterna', #12
             0x800 => 'Classic Negative', #forum10536
+            0x900 => 'Bleach Bypass', #forum10890
+            0xa00 => 'Nostalgic Neg', #forum12085
         },
     },
     0x1402 => { #2
@@ -624,7 +635,7 @@ my %faceCategories = (
         Writable => 'int16u',
         PrintHex => 1,
         PrintConv => {
-            0x000 => 'Auto (100-400%)',
+            0x000 => 'Auto',
             0x001 => 'Manual', #(ref http://forum.photome.de/viewtopic.php?f=2&t=353)
             0x100 => 'Standard (100%)',
             0x200 => 'Wide1 (230%)',
@@ -635,6 +646,7 @@ my %faceCategories = (
     0x1403 => { #2 (only valid for manual DR, ref 6)
         Name => 'DevelopmentDynamicRange',
         Writable => 'int16u',
+        # (shows 200, 400 or 800 for HDR200,HDR400,HDR800, ref forum10799)
     },
     0x1404 => { #2
         Name => 'MinFocalLength',
@@ -661,6 +673,15 @@ my %faceCategories = (
         PrintConv => '"$val%"',
         PrintConvInv => '$val=~s/\s*\%$//; $val',
     },
+    0x104e => { #forum10800 (X-Pro3)
+        Name => 'ColorChromeFXBlue',
+        Writable => 'int32s',
+        PrintConv => {
+            0 => 'Off',
+            32 => 'Weak', # (NC)
+            64 => 'Strong',
+        },
+    },
     0x1422 => { #8
         Name => 'ImageStabilization',
         Writable => 'int16u',
@@ -668,8 +689,9 @@ my %faceCategories = (
         PrintConv => [{
             0 => 'None',
             1 => 'Optical', #PH
-            2 => 'Sensor-shift', #PH
+            2 => 'Sensor-shift', #PH (now IBIS/OIS, ref forum13708)
             3 => 'OIS Lens', #forum9815 (optical+sensor?)
+            258 => 'IBIS/OIS + DIS', #forum13708 (digital on top of IBIS/OIS)
             512 => 'Digital', #PH
         },{
             0 => 'Off',
@@ -720,7 +742,11 @@ my %faceCategories = (
     0x1444 => { #12 (X-T3, only exists if DRangePriority is 'Auto')
         Name => 'DRangePriorityAuto',
         Writable => 'int16u',
-        PrintConv => { 1 => 'Weak', 2 => 'Strong' },
+        PrintConv => {
+            1 => 'Weak',
+            2 => 'Strong',
+            3 => 'Plus',    #forum10799
+        },
     },
     0x1445 => { #12 (X-T3, only exists if DRangePriority is 'Fixed')
         Name => 'DRangePriorityFixed',
@@ -816,6 +842,24 @@ my %faceCategories = (
             1 => 'Face',
             2 => 'Left Eye',
             3 => 'Right Eye',
+            7 => 'Body',
+            8 => 'Head',
+            11 => 'Bike',
+            12 => 'Body of Car',
+            13 => 'Front of Car',
+            14 => 'Animal Body',
+            15 => 'Animal Head',
+            16 => 'Animal Face',
+            17 => 'Animal Left Eye',
+            18 => 'Animal Right Eye',
+            19 => 'Bird Body',
+            20 => 'Bird Head',
+            21 => 'Bird Left Eye',
+            22 => 'Bird Right Eye',
+            23 => 'Aircraft Body',
+            25 => 'Aircraft Cockpit',
+            26 => 'Train Front',
+            27 => 'Train Cockpit',
         },'REPEAT'],
     },
     # 0x4202 int8u[-1] - number of cooredinates in each rectangle? (ref 11)
@@ -894,15 +938,22 @@ my %faceCategories = (
     WRITABLE => 1,
     0.1 => {
         Name => 'FocusMode2',
-        Mask => 0x000000ff,
+        Mask => 0x0000000f,
         PrintConv => {
-            0x00 => 'AF-M',
-            0x01 => 'AF-S',
-            0x02 => 'AF-C',
-            0x11 => 'AF-S (Auto)',
+            0x0 => 'AF-M',
+            0x1 => 'AF-S',
+            0x2 => 'AF-C',
         },
     },
     0.2 => {
+        Name => 'PreAF',
+        Mask => 0x00f0,
+        PrintConv => {
+            0 => 'Off',
+            1 => 'On',
+        },
+    },
+    0.3 => {
         Name => 'AFAreaMode',
         Mask => 0x0f00,
         PrintConv => {
@@ -911,7 +962,7 @@ my %faceCategories = (
             2 => 'Wide/Tracking',
         },
     },
-    0.3 => {
+    0.4 => {
         Name => 'AFAreaPointSize',
         Mask => 0xf000,
         PrintConv => {
@@ -919,7 +970,7 @@ my %faceCategories = (
             OTHER => sub { return $_[0] },
         },
     },
-    0.4 => {
+    0.5 => {
         Name => 'AFAreaZoneSize',
         Mask => 0xf0000,
         PrintConv => {
@@ -1638,7 +1689,7 @@ FujiFilm maker notes in EXIF information, and to read/write FujiFilm RAW
 
 =head1 AUTHOR
 
-Copyright 2003-2020, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
