@@ -6,6 +6,7 @@
 # Revisions:    2019-10-23 - P. Harvey Created
 #
 # References:   1) https://developer.parrot.com/docs/pdraw/metadata.html
+#               --> changed to https://developer.parrot.com/docs/pdraw/video-metadata.html
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Parrot;
@@ -13,7 +14,7 @@ package Image::ExifTool::Parrot;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 sub Process_mett($$$);
 
@@ -703,6 +704,7 @@ sub Process_mett($$$)
         $et->HandleTag($tagTbl, $id, undef,
             DataPt  => $dataPt,
             DataPos => $dataPos,
+            Base    => $$dirInfo{Base},
             Start   => $pos,
             Size    => $size,
         );
@@ -730,7 +732,7 @@ timed metadata from the 'mett' frame found in Parrot drone MP4 videos.
 
 =head1 AUTHOR
 
-Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
